==> libgdata_0.5.2.orig.tar.gz: libgdata-0.5.2/gdata/services/youtube/gdata-youtube-enums.h <==

/* Generated data (by glib-mkenums) */

#ifndef GDATA_YOUTUBE_ENUMS_H
#define GDATA_YOUTUBE_ENUMS_H

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "gdata-youtube-service.h" */
GType gdata_youtube_standard_feed_type_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_STANDARD_FEED_TYPE (gdata_youtube_standard_feed_type_get_type())
GType gdata_youtube_service_error_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_SERVICE_ERROR (gdata_youtube_service_error_get_type())
/* enumerations from "gdata-youtube-video.h" */
GType gdata_youtube_aspect_ratio_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_ASPECT_RATIO (gdata_youtube_aspect_ratio_get_type())
/* enumerations from "gdata-youtube-content.h" */
GType gdata_youtube_format_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_FORMAT (gdata_youtube_format_get_type())
/* enumerations from "gdata-youtube-query.h" */
GType gdata_youtube_safe_search_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_SAFE_SEARCH (gdata_youtube_safe_search_get_type())
GType gdata_youtube_sort_order_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_SORT_ORDER (gdata_youtube_sort_order_get_type())
GType gdata_youtube_age_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_AGE (gdata_youtube_age_get_type())
GType gdata_youtube_uploader_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_UPLOADER (gdata_youtube_uploader_get_type())
G_END_DECLS

#endif /* !GDATA_YOUTUBE_ENUMS_H */

/* Generated data ends here */

==> libgdata_0.6.4.orig.tar.gz: libgdata-0.6.4/gdata/services/youtube/gdata-youtube-enums.h <==

/* Generated data (by glib-mkenums) */

#ifndef GDATA_YOUTUBE_ENUMS_H
#define GDATA_YOUTUBE_ENUMS_H

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "./gdata/services/youtube/gdata-youtube-service.h" */
GType gdata_youtube_standard_feed_type_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_STANDARD_FEED_TYPE (gdata_youtube_standard_feed_type_get_type())
GType gdata_youtube_service_error_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_SERVICE_ERROR (gdata_youtube_service_error_get_type())
/* enumerations from "./gdata/services/youtube/gdata-youtube-video.h" */
GType gdata_youtube_aspect_ratio_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_ASPECT_RATIO (gdata_youtube_aspect_ratio_get_type())
/* enumerations from "./gdata/services/youtube/gdata-youtube-content.h" */
GType gdata_youtube_format_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_FORMAT (gdata_youtube_format_get_type())
/* enumerations from "./gdata/services/youtube/gdata-youtube-query.h" */
GType gdata_youtube_safe_search_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_SAFE_SEARCH (gdata_youtube_safe_search_get_type())
GType gdata_youtube_sort_order_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_SORT_ORDER (gdata_youtube_sort_order_get_type())
GType gdata_youtube_age_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_AGE (gdata_youtube_age_get_type())
GType gdata_youtube_uploader_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_YOUTUBE_UPLOADER (gdata_youtube_uploader_get_type())
G_END_DECLS

#endif /* !GDATA_YOUTUBE_ENUMS_H */

/* Generated data ends here */
